@@ -45,3 +45,6 @@ class TestBase(unittest.TestCase):
         assert_allclose(
             actual, desired, atol=delta, equal_nan=False, err_msg="", verbose=True
         )
+
+    def assertQPolynomialEqual(self, actual, desired):
+        self.assertTrue(actual == desired)
